==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/de/commands.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>CommandDialog</name>
    <message>
        <source>&lt;Back</source>
        <translation>&lt;Zurück</translation>
    </message>
    <message>
        <source>Next&gt;</source>
        <translation>Weiter&gt;</translation>
    </message>
    <message>
        <source>Complete</source>
        <translation>Fertigstellen</translation>
    </message>
    <message>
        <source>Command execution completed.</source>
        <translation>Befehlsausführunge vollendet.</translation>
    </message>
    <message>
        <source>Command execution canceled.</source>
        <translation>Befehlsausführung abgebrochen.</translation>
    </message>
    <message>
        <source>Requested operation failed: %1</source>
        <translation>Geforderte Operation fehlgeschlagen: %1</translation>
    </message>
    <message>
        <source>Executing command &apos;%1&apos; at %2</source>
        <translation>Führe Befehl &apos;%1&apos; bei %2 aus</translation>
    </message>
    <message>
        <source>Waiting for host response ...</source>
        <translation>Warte auf Hostantwort ...</translation>
    </message>
    <message>
        <source>Error: Can&apos;t send request to host.</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Commands</name>
    <message>
        <source>Ad-Hoc Commands</source>
        <translation>Ad-Hoc Befehle</translation>
    </message>
    <message>
        <source>Can not understand the specified action</source>
        <translation>Verstehe die beschriebene Aktion nicht</translation>
    </message>
    <message>
        <source>Can not accept the specified action</source>
        <translation>Kann die beschriebene Aktion nicht annehmen</translation>
    </message>
    <message>
        <source>Can not accept the specified language/locale</source>
        <translation>Kann die beschriebene Sprache/locale nicht annehmen</translation>
    </message>
    <message>
        <source>The data form did not provide one or more required fields</source>
        <translation>Das Datenformular stellt eines oder mehrere erforderliche Felder nicht bereit</translation>
    </message>
    <message>
        <source>Specified session not present</source>
        <translation>Gewählte Sitzung nicht präsent</translation>
    </message>
    <message>
        <source>Specified session is no longer active</source>
        <translation>Gewählte Sitzung ist nicht mehr aktiv</translation>
    </message>
    <message>
        <source>Execute</source>
        <translation>Ausführen</translation>
    </message>
    <message>
        <source>Commands</source>
        <translation>Befehle</translation>
    </message>
    <message>
        <source>Request commands</source>
        <translation>Befehle anfordern</translation>
    </message>
    <message>
        <source>Allows to perform special commands provided by various services</source>
        <translation>Erlaubt das Ausführen spezieller Befehle, die von verschiedenen Diensten angeboten werden</translation>
    </message>
    <message>
        <source>Supports the running or performing of the special services commands</source>
        <translation>Unterstütz den Betrieb oder das Ausführen von speziellen Dienstbefehlen</translation>
    </message>
    <message>
        <source>Forbidden</source>
        <translation></translation>
    </message>
</context>
</TS>

==> vacuum-1.1.2_1798.tar.xz: vacuum-1.1.2_1798/src/translations/de/commands.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>CommandDialog</name>
    <message>
        <source>&lt;Back</source>
        <translation>&lt;Zurück</translation>
    </message>
    <message>
        <source>Next&gt;</source>
        <translation>Weiter&gt;</translation>
    </message>
    <message>
        <source>Complete</source>
        <translation>Fertigstellen</translation>
    </message>
    <message>
        <source>Command execution completed.</source>
        <translation>Befehlsausführung beendet.</translation>
    </message>
    <message>
        <source>Command execution canceled.</source>
        <translation>Befehlsausführung abgebrochen.</translation>
    </message>
    <message>
        <source>Requested operation failed: %1</source>
        <translation>Angeforderte Operation fehlgeschlagen: %1</translation>
    </message>
    <message>
        <source>Executing command &apos;%1&apos; at %2</source>
        <translation>Führe Befehl &apos;%1&apos; bei %2 aus</translation>
    </message>
    <message>
        <source>Waiting for host response ...</source>
        <translation>Warte auf Antwort von Host ...</translation>
    </message>
    <message>
        <source>Error: Can&apos;t send request to host.</source>
        <translation>Fehler: Kann Anfrage an den Host nicht senden.</translation>
    </message>
</context>
<context>
    <name>Commands</name>
    <message>
        <source>Ad-Hoc Commands</source>
        <translation>Ad-Hoc Befehle</translation>
    </message>
    <message>
        <source>Can not understand the specified action</source>
        <translation>Verstehe die beschriebene Aktion nicht</translation>
    </message>
    <message>
        <source>Can not accept the specified action</source>
        <translation>Kann die beschriebene Aktion nicht annehmen</translation>
    </message>
    <message>
        <source>Can not accept the specified language/locale</source>
        <translation>Kann die beschriebene Sprache/Locale nicht annehmen</translation>
    </message>
    <message>
        <source>The data form did not provide one or more required fields</source>
        <translation>Das Datenformular stellt eines oder mehrere erforderliche Felder nicht bereit</translation>
    </message>
    <message>
        <source>Specified session not present</source>
        <translation>Angegebene Sitzung existiert nicht</translation>
    </message>
    <message>
        <source>Specified session is no longer active</source>
        <translation>Angegebene Sitzung ist nicht mehr aktiv</translation>
    </message>
    <message>
        <source>Execute</source>
        <translation>Ausführen</translation>
    </message>
    <message>
        <source>Commands</source>
        <translation>Befehle</translation>
    </message>
    <message>
        <source>Request commands</source>
        <translation>Befehle anfordern</translation>
    </message>
    <message>
        <source>Allows to perform special commands provided by various services</source>
        <translation>Erlaubt das Ausführen spezieller Befehle, die von verschiedenen Diensten angeboten werden</translation>
    </message>
    <message>
        <source>Supports the running or performing of the special services commands</source>
        <translation>Unterstützt den Betrieb oder das Ausführen von speziellen Dienstbefehlen</translation>
    </message>
    <message>
        <source>Forbidden</source>
        <translation>Verboten</translation>
    </message>
</context>
</TS>
